@@ -2,6 +2,7 @@ from typing import Optional, List
 
 from camel_model.camel_model import CamelModel
 
+from xlsx_lib.domain.autodiagnosis.AutodiagnosisData import AutodiagnosisData
 from xlsx_lib.domain.distribution.distribution_data import DistributionData
 from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
 from xlsx_lib.domain.electronic.electronic_element import ElectronicElement
@@ -21,3 +22,4 @@ class MotorcycleModel(CamelModel):
     frame: Optional[List[FrameElement]]
     power_supply: Optional[List[PowerSupplyComponent]]
     distribution: Optional[DistributionData]
+    autodiagnosis: Optional[AutodiagnosisData]
