@@ -5,6 +5,8 @@ from openpyxl import \
     Workbook, \
     load_workbook
 
+from xlsx_lib.domain.autodiagnosis.AutodiagnosisData import AutodiagnosisData
+from xlsx_lib.domain.autodiagnosis.AutodiagnosisSheet import AutodiagnosisSheet
 from xlsx_lib.domain.distribution.new_distribution_image import NewDistributionImage
 from xlsx_lib.domain.distribution.distribution_sheet import DistributionData, DistributionSheet
 from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
@@ -34,6 +36,7 @@ sheetnames_relationships = {
     "CHAS": Sheetnames.FRAME,
     "ALIM": Sheetnames.POWER_SUPPLY,
     "DISTRIBUCION": Sheetnames.DISTRIBUTION,
+    "AUTODIAGNOSIS": Sheetnames.AUTODIAGNOSIS,
 }
 
 
@@ -60,6 +63,7 @@ class MotorcycleModelWorkbook:
         frame_elements: Optional[List[FrameElement]] = None
         power_supply_components: Optional[List[PowerSupplyComponent]] = None
         distribution: Optional[DistributionData] = None
+        autodiagnosis: Optional[AutodiagnosisData] = None
 
         for sheetname in [key for key in workbook.sheetnames
                           if key in sheetnames_relationships]:
@@ -92,6 +96,9 @@ class MotorcycleModelWorkbook:
                 distribution = distribution_sheet.distribution_data
                 self.new_distribution_images = distribution_sheet.new_distribution_images
 
+            elif Sheetnames.AUTODIAGNOSIS == sheetnames_relationships[sheetname]:
+                autodiagnosis = AutodiagnosisSheet(worksheet=workbook[sheetname]).autodiagnosis
+
         self.motorcycle_model = MotorcycleModel(
             model_name=model_name,
             generic_replacements=generic_replacements,
@@ -101,4 +108,5 @@ class MotorcycleModelWorkbook:
             frame=frame_elements,
             power_supply=power_supply_components,
             distribution=distribution,
+            autodiagnosis=autodiagnosis,
         )
